pub struct Metadata { /* private fields */ }Expand description
Node metadata. This can be constructed by providing some compatible frame_metadata
which is then decoded into this. We aim to preserve all of the existing information in
the incoming metadata while optimizing the format a little for Subxt’s use cases.
Implementations
Sourceimpl Metadata
impl Metadata
Sourcepub fn arc(self) -> Arc<Metadata>
pub fn arc(self) -> Arc<Metadata>
Metadata tends to be passed around wrapped in an Arc so that it can be
cheaply cloned. This is a shorthand to return that.
Sourcepub fn decode_from(bytes: &[u8]) -> Result<Metadata, Error>
pub fn decode_from(bytes: &[u8]) -> Result<Metadata, Error>
This is essentially an alias for <Metadata as codec::Decode>::decode(&mut bytes)
Sourcepub fn from_v16(metadata: RuntimeMetadataV16) -> Result<Metadata, TryFromError>
pub fn from_v16(metadata: RuntimeMetadataV16) -> Result<Metadata, TryFromError>
Convert V16 metadata into Metadata.
Sourcepub fn from_v15(metadata: RuntimeMetadataV15) -> Result<Metadata, TryFromError>
pub fn from_v15(metadata: RuntimeMetadataV15) -> Result<Metadata, TryFromError>
Convert V15 metadata into Metadata.
Sourcepub fn from_v14(metadata: RuntimeMetadataV14) -> Result<Metadata, TryFromError>
pub fn from_v14(metadata: RuntimeMetadataV14) -> Result<Metadata, TryFromError>
Convert V14 metadata into Metadata.
Sourcepub fn types(&self) -> &PortableRegistry
pub fn types(&self) -> &PortableRegistry
Access the underlying type registry.
Sourcepub fn types_mut(&mut self) -> &mut PortableRegistry
pub fn types_mut(&mut self) -> &mut PortableRegistry
Mutable access to the underlying type registry.
Sourcepub fn dispatch_error_ty(&self) -> Option<u32>
pub fn dispatch_error_ty(&self) -> Option<u32>
The type ID of the DispatchError type, if it exists.
Sourcepub fn extrinsic(&self) -> &ExtrinsicMetadata
pub fn extrinsic(&self) -> &ExtrinsicMetadata
Return details about the extrinsic format.
Sourcepub fn outer_enums(&self) -> OuterEnumsMetadata
pub fn outer_enums(&self) -> OuterEnumsMetadata
Return details about the outer enums.
Sourcepub fn pallets(&self) -> impl ExactSizeIterator
pub fn pallets(&self) -> impl ExactSizeIterator
An iterator over all of the available pallets.
Sourcepub fn pallet_by_call_index(
&self,
variant_index: u8,
) -> Option<PalletMetadata<'_>>
pub fn pallet_by_call_index( &self, variant_index: u8, ) -> Option<PalletMetadata<'_>>
Access a pallet given some call/extrinsic pallet index byte
Sourcepub fn pallet_by_event_index(
&self,
variant_index: u8,
) -> Option<PalletMetadata<'_>>
pub fn pallet_by_event_index( &self, variant_index: u8, ) -> Option<PalletMetadata<'_>>
Access a pallet given some event pallet index byte
Sourcepub fn pallet_by_error_index(
&self,
variant_index: u8,
) -> Option<PalletMetadata<'_>>
pub fn pallet_by_error_index( &self, variant_index: u8, ) -> Option<PalletMetadata<'_>>
Access a pallet given some error pallet index byte
Sourcepub fn pallet_by_name(&self, pallet_name: &str) -> Option<PalletMetadata<'_>>
pub fn pallet_by_name(&self, pallet_name: &str) -> Option<PalletMetadata<'_>>
Access a pallet given its name.
Sourcepub fn runtime_api_traits(&self) -> impl ExactSizeIterator
pub fn runtime_api_traits(&self) -> impl ExactSizeIterator
An iterator over all of the runtime APIs.
Sourcepub fn runtime_api_trait_by_name(
&self,
name: &str,
) -> Option<RuntimeApiMetadata<'_>>
pub fn runtime_api_trait_by_name( &self, name: &str, ) -> Option<RuntimeApiMetadata<'_>>
Access a runtime API trait given its name.
Sourcepub fn custom(&self) -> CustomMetadata<'_>
pub fn custom(&self) -> CustomMetadata<'_>
Returns custom user defined types
Sourcepub fn hasher(&self) -> MetadataHasher<'_>
pub fn hasher(&self) -> MetadataHasher<'_>
Obtain a unique hash representing this metadata or specific parts of it.